<xsl:stylesheet version = "1.0" 
	xmlns:xsl = "http://www.w3.org/1999/XSL/Transform" 
	xmlns:xlink = "http://www.w3.org/1999/xlink" 
	xmlns:cf ="http://www.legalxml.org/ns/courtfiling11.dtd"> 
<xsl:template match = "/"> 
<html> 
 
	<head>
 
	<title><xsl:value-of select = "legal/courtDocument//documentType"/></title> 

	</head>
		<body style = "font-family: CG Times; font-size:10pt;  margin-left:10%;  margin-top:0.5cm; margin-right:10%"> 
			<xsl:apply-templates select = "legal//caseMetadata"/> 
			<xsl:apply-templates select = "legal//documentBody"/> 
			<xsl:apply-templates select = "legal//signers"/>
		</body> 
 
</html> 
</xsl:template> 


	<!-- This template displays the caption of the court document. -->
	<xsl:template match = "caseMetadata"> 
		<a>
			<xsl:attribute name = "href">
				<xsl:value-of select = "../documentMetadata//link/@xlink:href"/>
			</xsl:attribute>
			<xsl:value-of select = "../documentMetadata//link/@xlink:title"/>
		</a>

		<div align = "center" style = "font-weight:bold"> 
 		<xsl:value-of select = "court//courtName"/> 
		<xsl:if test="court[venue]">
			OF <xsl:value-of select="court//state"/>
			FOR <xsl:value-of select="court//county"/>
		</xsl:if>
			<br/> 
		</div> 
 
		<div style = "margin-top:0.5cm; background-color:#FFFFFF;  font-weight:bold"> 
			<table width = "100%" BORDER = "1" CELLPADDING = "10"> 
				<tr> 
					<td width = "50%"> 
						<xsl:for-each select = "caseTitle/party[@partyType='Plaintiff']"> 
							<xsl:value-of select = "organization/organizationName |  person/fullName"/>,<P/> 
							<xsl:value-of select = "@partyType"/>, 
						</xsl:for-each>
						<xsl:for-each select = "caseTitle/party[@partyType='Petitioner']"> 
							<xsl:value-of select = "organization/organizationName |  person/fullName"/>,<P/> 
							<xsl:value-of select = "@partyType"/>, 
						</xsl:for-each> 
						<P/>
						<xsl:value-of select = "caseTitle/vs"/> 
						<P/> 
						<xsl:for-each select = "caseTitle/party[@partyType='Defendant']"> 
							<xsl:value-of select = "organization/organizationName |  person/fullName"/>,<P/> 
							<xsl:value-of select = "@partyType"/>.<br/> 
						</xsl:for-each>
						<xsl:for-each select = "caseTitle/party[@partyType='Respondent']"> 
							<xsl:value-of select = "organization/organizationName |  person/fullName"/>,<P/> 
							<xsl:value-of select = "@partyType"/>.<br/> 
						</xsl:for-each> 
					</td>
 
					<td width = "50%" ALIGN = "LEFT">
						<div style = "margin-left:1cm"> 
							No.&#xa0;<xsl:value-of select = "fullCaseNumber"/> 
 							<br/> 
 							<xsl:for-each select = "relatedCase">  
								<xsl:if test = "contains(comment, 'Consolidated')"> 
									<xsl:value-of select = "fullCaseNumber"/>
									<br/> 
									(<xsl:value-of select = "comment"/>)<br/> 
								</xsl:if> 
							</xsl:for-each> 
							<br/>
							<br/> 
							<U><xsl:value-of select = "..//documentTitle"/></U> 
							<br/> 
						</div> 
					</td> 
				</tr> 
			</table>
 		</div>
		<p/> 
	</xsl:template> 
 
	<!-- This template displays the body of the court document. -->
	<xsl:template match = "documentBody">  
  
		<xsl:for-each select = "paragraphGroup"> 

			<xsl:if test="paragraphGroupTitle">
				<center><xsl:value-of select="paragraphGroupTitle"/></center>
				<p/>
			</xsl:if>

			<xsl:for-each select = "paragraph">
			<div style="text-indent:1.0cm">
				<xsl:choose>  
					<xsl:when test = "simpleCite"> 
						<xsl:apply-templates/> 
					</xsl:when> 

					<xsl:when test = "subparagraph1"> 
						<xsl:apply-templates/> 
					</xsl:when> 

					<xsl:when test = "addIn"> 
						<xsl:apply-templates/> 
					</xsl:when> 
 
					<xsl:when test = "phrase"> 
						<xsl:apply-templates/> 
					</xsl:when>

					<xsl:when test = "venue"> 
						<xsl:apply-templates/> 
					</xsl:when>

					<xsl:when test = "victim"> 
						<xsl:apply-templates/> 
					</xsl:when> 

					<xsl:otherwise> 
						<xsl:value-of select = "."/> 
					</xsl:otherwise> 
				</xsl:choose>
			</div>
		<br/>
		</xsl:for-each> 
	</xsl:for-each> 
 	<xsl:value-of select="dateTimeSigned"/>
</xsl:template> 
 
	<xsl:template match = "@list"> 
		<xsl:for-each select = "@listItem">
			<blockquote>
				<xsl:value-of select = "@label"/>. <xsl:value-of select = "."/> 
			</blockquote>
		</xsl:for-each> 
	</xsl:template>
 
	<xsl:template match = "subparagraph1"> 
		<blockquote> 
			<xsl:for-each select = "."> 
				<xsl:value-of select = "."/> 
			</xsl:for-each> 
		</blockquote> 
	</xsl:template> 

	<xsl:template match = "simpleCite"> 
		<i><xsl:value-of select = "."/></i> 
	</xsl:template> 
 
	<xsl:template match = "victim">
		<span style="color:navy">
			<b><xsl:value-of select = "."/></b>
		</span>
	</xsl:template>

	<xsl:template match = "phrase[@description='charge']">
		<b><xsl:value-of select = "."/></b> 
	</xsl:template>

	<xsl:template match = "addIn"> 
		<xsl:if test = "@addInType='prosecutor'"> 
			<b> 
				<xsl:value-of select = "//caseTitle/party/attorney/fullName"/> 
			</b> 
		</xsl:if>
   
		<xsl:if test = "@addInType='defendant'">
			<b> 
				<xsl:value-of select = "//caseMetadata/caseTitle/party/person/fullName"/> 
			</b> 
		</xsl:if>

		<xsl:if test = "@addInType='charge'"> 	
			<b><xsl:value-of select = "."/></b> 
		</xsl:if>

	</xsl:template> 
 	<!-- This template displays the signers of the court document. -->
	<xsl:template match = "signers"> 
		<p/> 
		<table width = "100%"> 
			<xsl:for-each select = "signatory"> 
				<tr> 
					<td width = "50%">
					</td>
					<td>
						<br/>
							<xsl:value-of select = "signatureLine"/>
						<br/>
						<xsl:if test = "attorney[fullName]"> 
							<xsl:value-of select = "attorney/fullName"/>, 
							<xsl:value-of select = "attorney/roleName"/> 
							<br/>  
						</xsl:if> 
					</td>
				</tr> 
			</xsl:for-each> 
		</table> 
	</xsl:template> 
 
</xsl:stylesheet>