<?xml version='1.0'?> 

<xsl:stylesheet version="1.0"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:xlink = "http://www.w3.org/1999/xlink"> 

 <xsl:variable name="ParaSymbol">&#182;</xsl:variable> 
 <xsl:variable name="RequiredSpaces"> 
 &#xa0;&#xa0;&#xa0;&#xa0;&#xa0;&#xa0;</xsl:variable> 
 <xsl:output method="html"/> 
 
 <!-- 
 ##################################################################### 
 --> 
 <!-- #USAGE - The root template sets out the HTML elements of 
the HTML page  into which the contents of the underlying XML document will be 
placed.	--> 
 
 <xsl:template match="/"> 
 
 <html> 
 <head> 
 
 <!-- 
 ********************************************************************* 
 --> 
 <!-- #USAGE - The following transforms the title of the document 
(i.e., the contents of the <documentTitle> element), into the title of the 
HTML age.  --> 
 
 <title><xsl:value-of select="legal/courtDocument//documentTitle"/>
</title> 
 
 </head> 
 
 <body style="font-family: CG Times; font-size:10pt; margin-left:10%; 
margin-top:0.5cm; margin-right:10%">

 <xsl:apply-templates select="legal//caseMetadata"/> 
  <xsl:apply-templates select="legal//documentBody"/> 
  <xsl:apply-templates select="legal//signers"/> 

<!-- This displays footnotes as endnotes to the document after the "signers" information. -->

	<xsl:for-each select="//footnote">
		<p/>
			<a>
				<xsl:attribute name="name">
					<xsl:value-of select="footnoteNumber"/>
				</xsl:attribute>
				<div style="font-size:10pt; font-weight:bold; display:inline; vertical-align:super">
					<xsl:value-of select="footnoteNumber"/>&#xa0;
				</div>
			</a>
		<xsl:value-of select="footnoteBody"/>
	</xsl:for-each>

 <xsl:apply-templates select="legal//proofOfService"/> 
 
 </body> 
 </html> 
 
 </xsl:template> 
 
 <xsl:template match="caseMetadata"> 
 
<a>
	<xsl:attribute name="href">
		<xsl:value-of select="../documentMetadata//link/@xlink:href"/>
	</xsl:attribute>
		<xsl:value-of select = "../documentMetadata//link/@xlink:title"/>
</a>
 
 <!-- ************************************************************ 
--> 
 
 <div align="center"> 
<p/>

<!-- Display <documentTitle> contents -->
<b>
	<xsl:value-of select="//documentTitle"/>
</b>
<p/>

<!-- Display parties -->

	<xsl:for-each select="caseTitle/party">
		<xsl:if test="contains (@partyType, 'PLAINTIFF')">
			<xsl:for-each select="person | organization | inRem">
				<xsl:value-of select="fullName | organizationName | inRemName"/>,
				<xsl:value-of select="../@partyType"/>
			</xsl:for-each>
		</xsl:if>
	</xsl:for-each>

 	&#xa0;<xsl:value-of select="caseTitle/vs"/>&#xa0;

	<xsl:for-each select="caseTitle/party">
		<xsl:if test="contains (@partyType, 'DEFENDANT')">
			<xsl:for-each select="person | organization | inRem">
				<xsl:value-of select="fullName | organizationName | inRemName"/>,
				<xsl:if test="aliasName">
					<xsl:value-of select="aliasName/@aliasType"/>&#xa0;
					<xsl:value-of select="aliasName"/>,&#xa0;
				</xsl:if>
				<xsl:if test="comment">
					<xsl:value-of select="comment"/>,&#xa0;
				</xsl:if>
				<xsl:if test="inRemName">
					IN REM,&#xa0;
				</xsl:if>
				<xsl:value-of select="../@partyType"/>.
			</xsl:for-each>
		</xsl:if>
	</xsl:for-each>
 <p/>

<!-- Display parties for related cases -->
<xsl:for-each select="relatedCase">
	<xsl:for-each select="caseTitle/party">
		<xsl:if test="contains (@partyType, 'PLAINTIFF')">
			<xsl:for-each select="person | organization | inRem">
				<xsl:value-of select="fullName | organizationName | inRemName"/>,
				<xsl:value-of select="../@partyType"/>
			</xsl:for-each>
		</xsl:if>
	</xsl:for-each>

 	&#xa0;<xsl:value-of select="caseTitle/vs"/>&#xa0;

	<xsl:for-each select="caseTitle/party">
		<xsl:if test="contains (@partyType, 'DEFENDANT')">
			<xsl:for-each select="person | organization | inRem">
				<xsl:value-of select="fullName | organizationName | inRemName"/>,
				<xsl:if test="aliasName">
					<xsl:value-of select="aliasName/@aliasType"/>&#xa0;
					<xsl:value-of select="aliasName"/>,&#xa0;
				</xsl:if>
				<xsl:if test="comment">
					<xsl:value-of select="comment"/>,&#xa0;
				</xsl:if>
				<xsl:if test="inRemName">
					IN REM,&#xa0;
				</xsl:if>
				<xsl:value-of select="../@partyType"/>.
			<p/>
			</xsl:for-each>
		</xsl:if>
	</xsl:for-each>
</xsl:for-each>

 <!-- Display case number -->

No.&#xa0;<xsl:value-of select="fullCaseNumber"/>
<xsl:for-each select="relatedCase[@relationshipType='consolidated']">
	,&#xa0;<xsl:value-of select="fullCaseNumber"/>
</xsl:for-each>

 <!-- Display court name -->
<p/>
<xsl:value-of select="court/courtName"/>,&#xa0;
<xsl:value-of select="court/courtCircuit"/>
<p/>

 <!-- Display date argued -->
Argued:&#xa0;&#xa0;<xsl:value-of select="..//date[@dateType='dateArgued']"/>.&#xa0;
<p/>
Decided:&#xa0;&#xa0;<xsl:value-of select="..//date[@dateType='dateDecided']"/>.&#xa0;
<p/>

<!-- Display names, firms, and addresses of attorneys -->
<xsl:for-each select="caseTitle/party">
	<xsl:if test="attorney/role[roleName='ARGUED']">
		<xsl:value-of select="attorney/role[roleName='ARGUED']"/>:
		<xsl:value-of select="attorney[role/roleName='ARGUED']/fullName"/>,&#xa0;
		<xsl:value-of select="attorney[role/roleName='ARGUED']//organizationName[@type='law firm']"/>,&#xa0;
		<xsl:value-of select="attorney[role/roleName='ARGUED']/postalAddress/city"/>,&#xa0;
		<xsl:value-of select="attorney[role/roleName='ARGUED']/postalAddress/state"/>,&#xa0;
		for&#xa0;<xsl:value-of select="@partyType"/>
	</xsl:if>
	<p/>
	<xsl:if test="attorney/role[roleName='ON BRIEF']">
		<xsl:value-of select="attorney/role[roleName='ON BRIEF']"/>:
		<xsl:value-of select="attorney[role/roleName='ON BRIEF']/fullName"/>,&#xa0;
		<xsl:value-of select="attorney[role/roleName='ON BRIEF']//organizationName[@type='law firm']"/>,&#xa0;
		<xsl:value-of select="attorney[role/roleName='ON BRIEF']/postalAddress/city"/>,&#xa0;
		<xsl:value-of select="attorney[role/roleName='ON BRIEF']/postalAddress/state"/>,&#xa0;
		for&#xa0;<xsl:value-of select="@partyType"/>
	</xsl:if>
</xsl:for-each>
 <p/>
</div>
____________________________________________________________________________________
 </xsl:template>
  
 
	<!-- 
#############################################################
-->
	
	<!-- This template displays the paragraphs in the body of the court 
document.  -->
	<xsl:template match = "documentBody">
	<p/>
		<xsl:if test="..//relatedCase[@relationshipType = 'appealed']">
			Appeal(s) from the <xsl:value-of select = "..//relatedCase[@relationshipType = 'appealed']//courtName"/>
			&#xa0;<xsl:value-of select = "..//relatedCase[@relationshipType = 'appealed']//courtDistrict"/>,
			&#xa0;at  <xsl:value-of select = "..//relatedCase[@relationshipType = 'appealed']//court//city"/>,
			&#xa0;<xsl:value-of select = "..//relatedCase[@relationshipType = 'appealed']//court//state"/>.
			&#xa0;<xsl:value-of select = "..//relatedCase[@relationshipType = 'appealed']//court//judicialOfficer/fullName"/>,
			&#xa0;<xsl:value-of select = "..//relatedCase[@relationshipType = 'appealed']//court//judicialOfficer/role"/>.
			<br/>
			(<xsl:for-each select="..//relatedCase[@relationshipType = 'appealed']">
				&#xa0;<xsl:value-of select="fullCaseNumber"/>
			</xsl:for-each>)
		</xsl:if>
		 <xsl:choose>
			<xsl:when test = "paragraphGroup">
			<xsl:if test="paragraphGroupTitle | paragraphTitle">
				<hr/>
				<b><xsl:value-of select="paragraphGroupTitle | paragraphTitle"/></b><p/>
			</xsl:if>
				<xsl:choose>
					<xsl:when test = "paragraph">
							<xsl:apply-templates select="//paragraph"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<!-- The following templates display the contents of elements within 
the <documentBody> element, including various <addIn> elements. -->

	<xsl:template match = "paragraphSubgroup1">
		<xsl:if test = "@title='Count'">
			<center>
				<xsl:value-of select = "@title"/>
				<xsl:if test = "@number">&#xa0;<xsl:value-of select = "@number"/>
					<p/>
				</xsl:if>
			</center>
		</xsl:if>
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "paragraph">
		<xsl:choose>
		<xsl:when test = "paragraphTitle">
			<center>
				<xsl:value-of select = "paragraphTitle"/>
				<xsl:if test = "@label">
					&#182;<xsl:value-of select = "@label"/>&#xa0;
				</xsl:if>
			</center>
			<xsl:apply-templates/>
		</xsl:when>
		<xsl:when test = "@type = 'dateArgued'">
			<div style="display:none">
				<xsl:apply-templates/>
			</div>
		</xsl:when>
		<xsl:otherwise>
			<xsl:if test = "@label">
				&#182;<xsl:value-of select = "@label"/>&#xa0;&#xa0;&#xa0;&#xa0;
			</xsl:if>
			<xsl:apply-templates />
		</xsl:otherwise>
		</xsl:choose>
		<br/>
		<br/>
	</xsl:template>

 	<xsl:template match="footnote"> 
		<span style="display:inline; font-size:8pt; font-weight:bold; vertical-align:super"> 
 			<a><xsl:attribute name="href">#<xsl:value-of select="footnoteNumber"/></xsl:attribute>
				<xsl:value-of select="footnoteNumber"/>
			</a>&#xa0;
		</span>
  	</xsl:template> 

	<xsl:template match = "addIn">
		<xsl:choose>
 		<xsl:when test="@addInType='quotationHeading'"> 
			<blockquote>
				<xsl:apply-templates/>
			</blockquote>
  		</xsl:when> 
		<xsl:when test="@addInType='quotationHeading'">
				<xsl:apply-templates/>&#xa0;
		</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
		</xsl:choose>
	</xsl:template>

	<xsl:template match="subparagraph1">
		<blockquote>
		<xsl:choose>
		<xsl:when test = "paragraphTitle">
			<center>
				<xsl:value-of select = "paragraphTitle"/>
				<xsl:if test = "@label">
					<xsl:value-of select = "@label"/>&#xa0;
				</xsl:if>
			</center>
			<xsl:apply-templates/>
		</xsl:when>
		<xsl:otherwise>
			<xsl:if test = "@label">
				<xsl:value-of select = "@label"/>.&#xa0;&#xa0;&#xa0;&#xa0;
			</xsl:if>
			<xsl:apply-templates />
		</xsl:otherwise>
		</xsl:choose>
		</blockquote>
	</xsl:template>

	<xsl:template match = "simpleCite">
		<i>
			<xsl:apply-templates/>
		</i>
	</xsl:template>

	<xsl:template match = "keyword">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "phrase">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "literal">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "quotation">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "date[@dateType]">
		<xsl:apply-templates/>
	</xsl:template>

	<xsl:template match = "list">
		<xsl:for-each select = "listItem">
			<xsl:if test = "@title">
				<p/>
				<b><xsl:value-of select = "@title | @label"/>:</b>&#xa0;&#xa0;</xsl:if>
			<p/>
			<xsl:value-of select = "."/>
		</xsl:for-each>
		<xsl:if test = "list">
			<xsl:for-each select = "list">
				<p/>
				<xsl:if test = "@title or @type">
					<b>
						<xsl:value-of select = "@title"/>&#xa0;<xsl:value-of select = "@type"/>&#xa0;
						<xsl:value-of select = "@label"/>
					</b>
				</xsl:if>
				<table width = "50%">
					<xsl:for-each select = "listItem">
						<tr>
							<td width = "50%">&#xa0;&#xa0;
								<b>
									<xsl:value-of select = "@title"/>
								</b>
							</td>
							<td>
								<xsl:value-of select = "."/>
							</td>
						</tr>
					</xsl:for-each>
				</table>
			</xsl:for-each>
		</xsl:if>
	</xsl:template>

 <!-- #################################################################  --> 
 
<!-- This template displays the contents of the <signers> 
 tag in the underlying XML document. --> 
 
 <xsl:template match="signers">
 
 <!-- This displays information regarding the signature line. --> 
 <p/>
 <table width="100%"> 
 
 <xsl:for-each select="signatory"> 
 	<tr>
 	<xsl:choose>
		<xsl:when test="contains(judicialOfficer[role/roleName],'Majority Author')">
 			<td width="50%"><td> 
 				<xsl:value-of select="signatureLine"/><br></br>
 				<xsl:value-of select="judicialOfficer/fullName"/>, 
				<xsl:value-of select="judicialOfficer//roleName"/> <br/><br/>
 			</td></td>
 		</xsl:when> 
		<xsl:when test="contains(judicialOfficer[role/roleName],'Concurring')">
    		<tr>
    		<td>
    		CONCURRING:<br/><br/>
    			<xsl:value-of select="signatureLine"/><br></br>
    			<xsl:value-of select="judicialOfficer/fullName"/>, 
				<xsl:value-of select="judicialOfficer//roleName"/> <br/><br/>
    		</td>
    		</tr>
        </xsl:when> 
    <xsl:otherwise>
    	<td width="50%"><td>
    		<xsl:value-of select="signatureLine"/><br></br> 
		 	<xsl:if test="attorney[fullName]"> 
 				<xsl:value-of select="attorney/fullName"/>, 
				<xsl:value-of select="attorney//roleName"/> <br/>
		  	</xsl:if> 
		</td></td>
	</xsl:otherwise>
    </xsl:choose>
	</tr> 

 </xsl:for-each> 

 </table> 
 </xsl:template> 
 </xsl:stylesheet> 


