<?xml version='1.0'?>

<xsl:stylesheet version="1.0"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
				xmlns:xlink = "http://www.w3.org/1999/xlink"> 

<xsl:output method="html"/>

<!-- 
##################################################################### 
-->
<!-- #USAGE - The root template sets out the HTML elements of the HTML page 
into which the contents of the underlying XML document will be placed.  -->

<xsl:template match="/"> 

<html> 
	<head> 

<!-- 
*********************************************************************
-->
<!-- #USAGE - The following transforms the title of the document (i.e., the 
contents of the <documentTitle> element), into the title of the HTML page.  -->

	<title><xsl:value-of select="//documentTitle"/></title> 

	</head> 

<!-- 
*********************************************************************
-->

<!-- This stylesheet contains subtemplates for displaying as HTML the 
contents of the child elements of the <courtDocument> element.  The child 
elements essentially are containers that label and hold information 
regarding the basic parts of the underlying pleading or discovery 
document. The following reads the output of these various templates into 
the HTML document in the order listed.  Changing the order of the 
subtemplates changes the order in which their output is read into the 
root template. -->

<body style="font-size:12pt; margin-left:1.0in; margin-top:0.5cm; margin-right:1.0in">

<xsl:apply-templates select="legal//caseMetadata"/>
<xsl:apply-templates select="legal//documentBody"/>
<p/>
<xsl:apply-templates select="legal//signers"/>
<p/>
<xsl:apply-templates select="legal//proofOfService"/>
<p/>
<xsl:apply-templates select="legal//attachedItem"/>

</body> 
</html> 

</xsl:template>

<!-- 
#################################################################
-->

<!-- This template displays the contents of the <caseCaption> element in 
the underlying XML document. -->

<xsl:template match="caseMetadata">

<!-- 
*********************************************************************
-->

<!-- #USAGE - This displays the contents of the <court> element 
in the <caseCaption> tag. The <court> element contains 
information about the address or location, type, and name of the court 
in which the case has been filed. -->

	<table width='100%'>
		<tr>
		<td width='50%'>

		<div style="font-weight:bold">
			<xsl:value-of select="court//state"/>
			<br></br>
			<br></br>
			<xsl:value-of select="court//county"/>
		</div>
		</td>

		<td width='50%' align='center'>
		<div style="font-weight:bold">
			<xsl:value-of select="court/courtName"/><br/> 
			<xsl:value-of select="court/courtDivision"/><br/>
			<xsl:value-of select="fullCaseNumber"/> 
		</div>
		</td>
		</tr>
	</table>

<!-- 
*********************************************************************
-->

<!-- This creates a case caption CSS-type box and table to contain both 
the <party> box and the <documentTitle> box.  
This displays the colors, border, and size of the box around the tags in 
the <caseCaption>. -->

<div style="margin-top:0.5cm; background-color:#EAEAEA; font-weight:bold">
<table width='100%' border='1' padding="10px">

<!-- 
*********************************************************************
-->
<!-- #USAGE - This displays the contents of each <party> tag having a 
partyType attribute containing the text "Petitioner" or "Plaintiff". -->

	<tr>
	<td width='50%'>
	<xsl:for-each select="caseTitle/party[@partyType='Plaintiff']">
		<div style="display:inline">
		<xsl:value-of select="organization/organizationName | person/fullName"/>
			<xsl:if test="organization/aliasName">
				&#xa0;<xsl:value-of select="organization/aliasName/@aliasType"/>
				&#xa0;<xsl:value-of select="organization/aliasName"/>
			</xsl:if>,
		</div>
	</xsl:for-each>

	<xsl:for-each select="caseTitle/party[@partyType='Petitioner']">
		<div style="display:inline">
		<xsl:value-of select="organization/organizationName | person/fullName"/>,
		</div>
	</xsl:for-each>
	
	<div style="margin-top:0.25cm; margin-left:1cm">
	<xsl:value-of select="caseTitle/party/@partyType"/>,
	</div>

<!-- 
********************************************************************
-->

<!-- #USAGE - The following displays the contents of the <vs> tag.  -->

	<div style="margin-top:0.25cm; margin-bottom:0.25cm; margin-left:0.5cm">
		vs.
	</div>

<!-- 
*********************************************************************
-->
<!-- This displays the contents of each <party> tag that contains a 
partyType attribute containing the text "Defendant" or "Respondent". -->

<xsl:for-each select="caseTitle/partyGroup/party[@partyType='Defendant'] | caseTitle/party[@partyType='Defendant']">
		<div style="display:inline">
		<xsl:value-of select="organization/organizationName | person/fullName"/>
			<xsl:if test="organization/aliasName">
				&#xa0;<xsl:value-of select="organization/aliasName/@aliasType"/>
				&#xa0;<xsl:value-of select="organization/aliasName"/>
			</xsl:if>,
		<div style="display:inline">
		<xsl:if test="organization/roleName | person/roleName">
			<xsl:value-of select="organization/roleName | person/roleName"/>,&#xa0;
		</xsl:if>
		</div>
		</div>
</xsl:for-each>

<xsl:for-each select="caseTitle/party[@partyType='Respondent']">
		<div style="display:inline">
		<xsl:value-of select="organization/organizationName | person/fullName"/>,
		<div style="display:inline">
		<xsl:if test="organization/roleName | person/roleName">
			<xsl:value-of select="organization/roleName | person/roleName"/>,&#xa0;
		</xsl:if>
		</div>
		</div>
</xsl:for-each>

<!-- 
*********************************************************************
-->

<!-- This displays the contents of the partyType attributes containing the 
text "Defendant" or "Respondent". -->

		<div style="margin-top:0.25cm; margin-left:1cm">
		<xsl:value-of select="caseTitle/party[@partyType='Defendant']/@partyType"/>
		<xsl:value-of select="caseTitle/party[@partyType='Respondent']/@partyType"/>.
		</div>

	</td>

<!-- 
*********************************************************************
-->

<!-- This displays the contents of the <documentTitle> tag. -->

	<td width='50%' align='CENTER'>
		<xsl:value-of select="//documentTitle"/>
	</td>
	</tr>

</table>
</div>

</xsl:template>

<!-- 
#############################################################
-->

<!-- This template displays the paragraphs in the body of the court 
document. -->

<xsl:template match="documentBody">
<br/><br/>
		<xsl:if test = "paragraph">
			<xsl:apply-templates select = "paragraph"/>
		</xsl:if>
		<xsl:if test = "paragraphGroup">
			<xsl:for-each select = "paragraphGroup">
				<center><b><xsl:value-of select="paragraphGroupTitle"/></b></center><p/>
				<xsl:choose>
					<xsl:when test = "paragraph">
						<xsl:apply-templates select="paragraph"/>
					</xsl:when>
					<xsl:otherwise>
						<xsl:apply-templates/>
					</xsl:otherwise>
				</xsl:choose>
			</xsl:for-each>
		</xsl:if>

<!-- The following displays the contents of the <dateTimeSigned> 
tag in the underlying XML document. -->

		<xsl:if test="dateTimeSigned">
			Date:&#xa0;<xsl:value-of select = "dateTimeSigned"/>
		</xsl:if>
	</xsl:template>

<!-- The following displays the contents of the <paragraph> 
elements in the underlying XML document. -->

	<xsl:template match="paragraph">
		<xsl:if test="@label">
			<xsl:value-of select="@label"/>.&#xa0;&#xa0;
		</xsl:if>
		<xsl:apply-templates/>
		<p/>
	</xsl:template>
			
	<xsl:template match="subparagraph1">
		<blockquote>
			<xsl:choose>
			<xsl:when test="subparagraphTitle">
				<u><b><xsl:value-of select="subparagraphTitle"/>:</b></u>&#xa0;&#xa0;
			</xsl:when>
			<xsl:when test="@label">
				<xsl:value-of select="@label"/>.&#xa0;&#xa0;
				<xsl:apply-templates/>
			</xsl:when>
			<xsl:otherwise>
				<xsl:apply-templates/>
			</xsl:otherwise>
			</xsl:choose>
		</blockquote>
	</xsl:template>
	
	<xsl:template match="list">
		<ol>
			<xsl:for-each select="listItem">
				<li><xsl:value-of select="."/></li>
			</xsl:for-each>
		</ol>
	</xsl:template>

<!-- 
#####################################################################

-->
<!-- #USAGE - This template displays the contents of the 
<signers> tag in the underlying XML document. -->

<xsl:template match="signers">

<!-- 
*********************************************************************
-->

<!-- This displays information regarding the signature line and each 
attorney's name. -->

<div style="margin-left:50%; margin-bottom:0.25cm; text-align:left">
	<xsl:for-each select="signatory/signatureLine">
		<b><xsl:value-of select="."/><br></br></b>
	</xsl:for-each>
	<xsl:for-each select="signatory//fullName">
		<xsl:value-of select="."/><br></br>
	</xsl:for-each>
	<xsl:value-of select="signatory//roleName"/>
	<p/>
	<xsl:for-each select="signatory//postalAddress">
		<xsl:for-each select="addressLine">
			<xsl:value-of select="."/><br></br>
		</xsl:for-each>
		<xsl:value-of select="city"/>,&#xa0;
		<xsl:value-of select="state"/>&#xa0;
		<xsl:value-of select="postalCode"/><br></br>
		<xsl:if test="../fullTelephone">
			<xsl:value-of select="../fullTelephone"/><br></br>
		</xsl:if>
		<xsl:if test="../fullFax">
			<xsl:value-of select="../fullFax"/><br></br>
		</xsl:if>
		<xsl:if test="../email">
			<xsl:value-of select="../email"/><br></br>
		</xsl:if>
		<P/>
	</xsl:for-each>

	</div>
	
	<xsl:if test="notarization">
		<xsl:apply-templates select="notarization"/>
	</xsl:if>
</xsl:template>
<!-- 
#####################################################################
-->

<!-- The following template displays the contents of the Notarization 
element. -->

	<xsl:template match="notarization">
	
	<div style="display:block">
		<xsl:for-each select="signatory/signatureLine">
			<xsl:value-of select="."/><br/>
		</xsl:for-each>
		<xsl:value-of select="signatory//fullName"/><br/>
		<xsl:value-of select="signatory//roleName"/><br/>
		<xsl:value-of select="notaryDate"/><br/>
		<xsl:value-of select="notarySeal"/><P/>
		<xsl:value-of select="notaryExpiration"/><P/>
	</div>

	</xsl:template>

<!-- 
#####################################################################
-->
<!-- #USAGE - This template displays the contents of the certificate of 
service. -->

<xsl:template match="proofOfService">

<!-- 
*********************************************************************
-->
<!-- #USAGE - This displays the heading and contents paragraphs in the 
certificate of service. -->

	<center>
	<xsl:value-of select="paragraphTitle"/>
	</center>
	<div style="width:100%; margin-top:0.25cm; text-indent:1cm; 
font-weight:normal">
	<xsl:apply-templates select="paragraph/text()"/>
	<br></br>
	<br></br>
	</div>
	
<!-- 
*********************************************************************
-->
<!-- #USAGE - This displays the name and address of the person(s) being 
served with the pleading or discovery document. -->

	<div style="width:85%; margin-left:2cm">
	<xsl:for-each select="paragraph/attorney">
		<div style="font-weight:bold">
		<xsl:value-of select="fullName"/>
		<xsl:value-of select="@Identifier" />
		</div>
	
	<xsl:for-each select="postalAddress">
		<xsl:for-each select="addressLine">
			<xsl:value-of select="."/><br></br>
		</xsl:for-each>
		<xsl:value-of select="city"/>,
		<xsl:value-of select="state"/>
		&#xa0;<xsl:value-of select="postalCode"/><br></br>
		<xsl:if test="fullTelephone">
			<xsl:value-of select="fullTelephone"/><br></br>
		</xsl:if>
		<xsl:if test="fullFax">
			<xsl:value-of select="fullFax"/><br></br>
		</xsl:if>
		<xsl:if test="email">
			<xsl:value-of select="email"/><br></br>
		</xsl:if>
		<P/>
	</xsl:for-each>
	</xsl:for-each>
	</div>

<!-- 
*********************************************************************
-->
<!-- #USAGE - This displays the contents of the <dateTimeServed> element 
in the certificate of service. -->

	<xsl:value-of select="dateTimeServed"/>
	
<!-- 
*********************************************************************
-->
<!-- #USAGE - This displays the contents of the signature information 
in the certificate of service. -->

	<div style="margin-top:1cm; margin-left:50%">
	<xsl:for-each select="signatory/signatureLine">
		<xsl:value-of select="."/><br></br>
	</xsl:for-each>
	<xsl:for-each select="signatory//fullName">
		<xsl:value-of select="."/><br></br>
	</xsl:for-each>
	<xsl:value-of select="signatory//roleName"/>
	</div>

</xsl:template>

<!-- 
#################################################################
-->

<xsl:template match="attachedItem">
	<xsl:for-each select="attachedItemContent">
		<xsl:if test="@href">
			<a>
				<xsl:attribute name="href">
					<xsl:value-of select="@href"/>
				</xsl:attribute>
				<xsl:value-of select="../documentMetadata/documentTitle"/>
			</a>
			<p/>
		</xsl:if>
	</xsl:for-each>
</xsl:template>

</xsl:stylesheet>
