<?xml version='1.0'?>
<xsl:stylesheet version="1.0"
				xmlns:xsl="http://www.w3.org/1999/XSL/Transform">
<xsl:output method="text"/>
<xsl:template match="/">{\rtf1\ansi\deff0\deftab720{\fonttbl{\f0\fswiss MS Sans Serif;}{\f1\froman\fcharset2 Symbol;}{\f2\froman Times New Roman;}{\f3\froman Times New Roman;}}
{\colortbl\red0\green0\blue0;\red0\green0\blue128;}
<!-- *************************************************************************** -->
<!-- ###The output of the templates for the various parts of the xml document are placed in the root template of the stylesheet here.### -->
<xsl:apply-templates select="legal/courtDocument/caseMetadata"/>
<xsl:apply-templates select="legal/courtDocument/documentBody"/>
<xsl:apply-templates select="legal/courtDocument/signers"/>
}
</xsl:template>
<!-- *************************************************************************** -->
<xsl:template match="caseMetadata">
<!-- ###The location and name of the court.### -->
\deflang1033\pard\plain\f2\fs24\b <xsl:value-of select="court/venue/state"/>\plain\f2\fs24
\par \pard\qc\plain\f2\fs24\b <xsl:value-of select="court/courtName"/> OF <xsl:value-of select="court/venue/county"/>\plain\f2\fs24
<!-- ###The case number(s).### -->
<xsl:for-each select="fullCaseNumber">
\par <xsl:value-of select="."/>
</xsl:for-each>
\par 
<!-- *************************************************************************** -->
<!-- ###The contents of each <party> tag having a partyType attribute containing the string "Complainant".### -->
<xsl:for-each select="caseTitle/party[@partyType='Complainant']">
\par \pard\plain\f2\fs24\b <xsl:value-of select="person/fullName"/>,\plain\f2\fs24
<xsl:for-each select="person/postalAddress/addressLine">
\par \tab <xsl:value-of select="."/>
</xsl:for-each>
\par \tab <xsl:value-of select="person/postalAddress/city"/>, 
 <xsl:value-of select="person/postalAddress/state"/> 
\tab <xsl:value-of select="person/postalAddress/postalCode"/>
</xsl:for-each>

<!-- ###The contents of <roleName> for the Complainant/Plaintiff.  -->
\par 
\par \tab <xsl:value-of select="caseTitle/party[@partyType='Complainant']/person//roleName"/>,
<!-- *************************************************************************** -->
<!-- ###The following displays the contents of the "Vs" tag.###  -->
\par 
\par \tab <xsl:value-of select="vs"/>
\par 
<!-- *************************************************************************** -->
<!-- ###The contents of each <party> tag having a partyType attribute containing the string "Respondent".### -->
<xsl:for-each select="caseTitle/party[@partyType='Respondent']">
\par \pard\plain\f2\fs24\b <xsl:value-of select="person/fullName"/>,\plain\f2\fs24
 <xsl:for-each select="person/postalAddress/addressLine">
\par \tab <xsl:value-of select="."/>
</xsl:for-each>
\par \tab <xsl:value-of select="person/postalAddress/city"/>,  
<xsl:value-of select="person/postalAddress/state"/> 
\tab <xsl:value-of select="person/postalAddress/postalCode"/>
</xsl:for-each>
\par 
\par \tab <xsl:value-of select="caseTitle/party[@partyType='Respondent']/person//roleName"/>
<!-- *************************************************************************** -->
<!-- ###The contents of the <documentTitle> tag.### -->
\par
\par \pard\qc\plain\f2\fs24\b <xsl:value-of select="//documentTitle"/>\plain\f2\fs24 
\par \pard\plain\f2\fs24 
</xsl:template>
<!-- *************************************************************************** -->
<!-- ###This template displays the paragraphs in the body of the document.### -->
<xsl:template match="documentBody">
<xsl:for-each select="paragraphGroup">
<xsl:for-each select="paragraph">
\par <xsl:if test="@label"> \tab
<xsl:value-of select="@label"/> \tab
</xsl:if>
<xsl:choose>	
<xsl:when test="subparagraph1">
<xsl:apply-templates />
\par 
</xsl:when>
<xsl:otherwise>
<xsl:value-of select="." />
\par 
</xsl:otherwise>
</xsl:choose>
</xsl:for-each>

</xsl:for-each>
<!-- *************************************************************************** -->
<!-- ###The contents of the <dateTimeSigned> tag.### -->
\par \tab <xsl:value-of select="dateTimeSigned"/>
\par
</xsl:template>
<!-- *************************************************************************** -->
<!-- ###The templates for the contents of the subparagraph1 elements.### -->
<xsl:template match="subparagraph1">
\par
\par \tab \pard\li720\plain\f2\fs24 <xsl:value-of select="@label"/>. \tab <xsl:apply-templates/>
\pard\plain\f2\fs24
</xsl:template>
<!-- *************************************************************************** -->
<!-- ###The contents of the <signers> tag.### -->
<xsl:template match="signers">
\par \pard\li4680\plain\f2\fs24\b <xsl:value-of select="signatory/signatureLine"/>
<xsl:for-each select="signatory/attorney">
\par <xsl:value-of select="fullName"/>\plain\f2\fs24
\par <xsl:value-of select="barNumber/@issuingAuthority"/> Bar: <xsl:value-of select="barNumber" />
<xsl:for-each select="postalAddress/addressLine">
\par <xsl:value-of select="."/>
</xsl:for-each>
\par <xsl:value-of select="postalAddress/city"/>,
<xsl:value-of select="postalAddress/state"/>
<xsl:value-of select="postalAddress/postalCode"/>
\par Phone: <xsl:value-of select="fullTelephone"/>
\par Fax: <xsl:value-of select="fullFax"/>
<!-- *************************************************************************** -->
<!-- ###The contents of the <roleName> element for the signer.### -->
\par <xsl:value-of select=".//roleName"/>
</xsl:for-each>
</xsl:template>
</xsl:stylesheet>